@@ -330,8 +330,9 @@ class language_learner:
         self.create_entry_rounds()
         self.create_entry_timer()
         self.create_menu()
+        # self.create_score
         # self.creat_buttons()
-
+        self.retry_times = 0
 
     def delete_privious_buttons(self):
         if len(self.button_object_list) > 0:
@@ -344,9 +345,9 @@ class language_learner:
         n = len(self.input_text)
         # print(input_text)
 
+        cols = 15
+        rows =ceil(n/cols)
 
-        rows =15
-        cols = ceil(n/rows)
 
         # if cols>7:
         #     button_size=ceil(1270 /(cols*2.23))
@@ -361,11 +362,11 @@ class language_learner:
             for i in range(cols):
                 if n>0:
                     t = text_display_button(root = self.top,
-                    input_text=self.input_text[i*cols+j],
+                    input_text=self.input_text[i+j*cols],
                     button_size = button_size,
                     path_name=self.path_source)
                     # t.grid(row=j+1, column=i)
-                    t.place(relx=0.05+j*0.06, rely=0.35+i*0.12)
+                    t.place(relx=0.05+i*0.06, rely=0.25+j*0.12)
                     self.button_object_list.append(t)
                     n = n-1
 
@@ -443,7 +444,7 @@ class language_learner:
         self.button_check.configure(text='''Check''')
         self.button_check.configure(font=self.font_s)
         self.button_check.config(command = self.button_check_callback)
-        self.button_check.config(state= "disabled")
+        # self.button_check.config(state= "disabled")
 
     def create_button_before(self):
         self.button_before = tk.Button(self.top)
@@ -528,8 +529,10 @@ class language_learner:
         self.fileMenu = Menu(self.menu)
         self.fileMenu.add_command(label="Open",command=self.menu_open_callback)
         self.fileMenu.add_command(label="Type", command=self.menu_type_callback)
-        self.fileMenu.add_command(label="Order", command=self.menu_order_callback)
+        # self.fileMenu.add_command(label="Order", command=self.menu_order_callback)
         self.fileMenu.add_command(label="Exit", command=self.menu_Exit_callback)
+        self.fileMenu.entryconfig(2, state=DISABLED)
+        # self.fileMenu.entryconfig(3, state=DISABLED)
         self.menu.add_cascade(label="File", menu=self.fileMenu)
 
     def button_start_callback(self):
@@ -548,10 +551,12 @@ class language_learner:
                 self.rounds_val.set(str(r))
                 txt = self.report_dict['problem'][self.problem_index]
                 self.input_text = txt
+
                 self.delete_privious_buttons()
                 self.creat_buttons()
                 self.label_word.configure(text='')
                 self.report_dict['time'][self.problem_index-1]=int(self.timer_config)-int(self.time_val.get())
+                self.read(self.input_text)
 
             if self.problem_index == self.rounds_config:
                 self.button_start['text'] = 'Submit'
@@ -583,9 +588,9 @@ class language_learner:
     def button_read_callback(self):
         if self.button_read['text'] == 'Read':
             # txt = self.label_word['text']
-            print(self.input_text)
+            # print(self.input_text)
             txt = self.input_text
-            self.read(txt)
+            self.read(self.input_text)
             if self.problem_index <= self.rounds_config and self.problem_index>0:
                 # txt = self.report_dict['problem'][self.problem_index-1]
                 self.report_dict['if_read'][self.problem_index-1] = True
@@ -630,6 +635,32 @@ class language_learner:
                     self.report_dict['similarity'][self.problem_index-1] = similarity
                     self.report_dict['recognization'][self.problem_index-1] = txt
 
+
+                    if self.retry_times < 5:
+                        if similarity > 90 :
+                            messagebox.showinfo('Very GOOD!', "Very GOOD! You got "+str(similarity))
+                            self.button_start_callback()
+                            self.retry_times =0
+                        elif similarity >60:
+                            res = messagebox.askquestion("Not bad",
+                                           "It is not bad. You get "+str(similarity)+'. Would you make another try?')
+                            if res == 'yes':
+                                self.retry_times +=1
+                                self.button_record_callback()
+
+                            elif res == 'no':
+                                self.retry_times =0
+                                self.button_start_callback()
+                        elif similarity<=60:
+                            messagebox.showinfo('Not OK', "Hmm, You only got "+str(similarity)+'. Please try agagin!')
+                            self.retry_times +=1
+                            self.button_record_callback()
+                    else:
+                        messagebox.showinfo('Not OK', 'Hmm, You try too many times, let us skip this')
+                        self.retry_times =0
+                        self.button_start_callback()
+
+
         elif self.button_record['text'] == 'NOK':
             if self.problem_index <= self.rounds_config and self.problem_index>0:
                 self.report_dict['correct'][self.problem_index-1] = 0
@@ -812,6 +843,7 @@ class language_learner:
         self.rounds_val.set(len(self.df_f))
         self.button_start.config(text = 'Start')
         self.button_start.config(state = 'normal')
+        self.fileMenu.entryconfig(2, state=NORMAL)
 
     def initialize_widgets_for_start(self):
         if self.time_val.get() != 'Timer':
